==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Polji");
define("_URL","URL");
define("_PRINTER","Prilagojeno za izpis");
define("_FRIEND","Novico polji prijatelju");
define("_YOURNAME","Vae ime");
define("_OK","V redu");
define("_RELATED","Vezane povezave");
define("_MOREABOUT","Ve o");
define("_NEWSBY","lanek je napisal");
define("_MOSTREAD","Najvekrat prebran lanek o");
define("_READMORE","Preberi...");
define("_BYTESMORE","bytov");
define("_COMMENTSQ","imate komentar?");
define("_COMMENT","komentar");
define("_CONFIGURE","Konfiguriraj");
define("_LOGINCREATE","Vstop/Izdelaj raun");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","Brez komentarja");
define("_NESTED","Vgnezdeno");
define("_FLAT","Plosko");
define("_THREAD","Nit");
define("_OLDEST","Stareje");
define("_NEWEST","Noveje");
define("_HIGHEST","Z najvijim rezultatom");
define("_COMMENTSWARNING","Vsi komentarji so lastnitvo osebe, ki jih je napisala. Za njihovo vsebino ne odgovarjamo.");
define("_SCORE","Ocena:");
define("_USERINFO","Informacije o uporabniku");
define("_READREST","Preberi ostanek tega komentarja...");
define("_REPLY","Odgovori na to");
define("_REPLYMAIN","Komentiraj");
define("_NOSUBJECT","Brez naslova");
define("_NOANONCOMMENTS","Komentiranje anonimnim uporabnikom ni dovoljeno, <a href=\"modules.php?name=Your_Account\">registrirajte se</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Komentar");
define("_ALLOWEDHTML","HTML koda je dovoljena:");
define("_POSTANON","Polji anonimno");
define("_EXTRANS","Extrans (html tag v tekstu)");
define("_HTMLFORMATED","HTML formatirano");
define("_PLAINTEXT","Normalen tekst");
define("_ONN","na...");
define("_SUBJECT","Naslov");
define("_COMMENTREPLY","Odgovori na komentar");
define("_COMREPLYPRE","Pregled/preverjanje pred poiljanjem");
define("_NOTRIGHT","Nekaj ni v redu s prehodom variable ez to funkcijo. Smisel tega sporoila je reevanje mogoih napak");
define("_SENDAMSG","Polji sporoilo");
define("_YOUSENDSTORY","Poslali boste zgodbo");
define("_TOAFRIEND","doloenemu prijatelju:");
define("_FYOURNAME","Vae ime:");
define("_FYOUREMAIL","Va E-mail:");
define("_FFRIENDNAME","Ime Vaega prijatelja:");
define("_FFRIENDEMAIL","E-mail Vaega prijatelja:");
define("_INTERESTING","Zanimiv lanek na");
define("_HELLO","Pozdravljen");
define("_YOURFRIEND","Vaemu prijatelju");
define("_CONSIDERED","se zdi sledei lanek zanimiv in Vam ga eli poslati.");
define("_FDATE","Datum:");
define("_FTOPIC","Naslov:");
define("_YOUCANREAD","Lahko prebere zanimiv lanek na");
define("_FSTORY","lanek");
define("_HASSENT","Je poslan na");
define("_THANKS","Hvala");
define("_RECOMMEND","Priporoi stran prijatelju");
define("_PDATE","Datum:");
define("_PTOPIC","Naslov:");
define("_COMESFROM","lanek prihaja od");
define("_THEURL","URL lanka je:");
define("_PREVIEW","Pregled");
define("_NEWUSER","Novi uporabnik");
define("_OPTIONS","Opcije");
define("_REFRESH","Osvei");
define("_ADD","Dodaj");
define("_NOCOMMENTSACT","Oprostite, komentarji za ta lanek niso dostopni.");
define("_ARTICLEPOLL","Anketa lanka");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-slovenian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Polji");
define("_URL","URL");
define("_PRINTER","Prilagojeno za izpis");
define("_FRIEND","Novico polji prijatelju");
define("_YOURNAME","Vae ime");
define("_OK","V redu");
define("_RELATED","Vezane povezave");
define("_MOREABOUT","Ve o");
define("_NEWSBY","lanek je napisal");
define("_MOSTREAD","Najvekrat prebran lanek o");
define("_READMORE","Preberi...");
define("_BYTESMORE","bytov");
define("_COMMENTSQ","imate komentar?");
define("_COMMENT","komentar");
define("_CONFIGURE","Konfiguriraj");
define("_LOGINCREATE","Vstop/Izdelaj raun");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","Brez komentarja");
define("_NESTED","Vgnezdeno");
define("_FLAT","Plosko");
define("_THREAD","Nit");
define("_OLDEST","Stareje");
define("_NEWEST","Noveje");
define("_HIGHEST","Z najvijim rezultatom");
define("_COMMENTSWARNING","Vsi komentarji so lastnitvo osebe, ki jih je napisala. Za njihovo vsebino ne odgovarjamo.");
define("_SCORE","Ocena:");
define("_USERINFO","Informacije o uporabniku");
define("_READREST","Preberi ostanek tega komentarja...");
define("_REPLY","Odgovori na to");
define("_REPLYMAIN","Komentiraj");
define("_NOSUBJECT","Brez naslova");
define("_NOANONCOMMENTS","Komentiranje anonimnim uporabnikom ni dovoljeno, <a href=\"modules.php?name=Your_Account\">registrirajte se</a>");
define("_PARENT","Parent");
define("_ROOT","Root");
define("_UCOMMENT","Komentar");
define("_ALLOWEDHTML","HTML koda je dovoljena:");
define("_POSTANON","Polji anonimno");
define("_EXTRANS","Extrans (html tag v tekstu)");
define("_HTMLFORMATED","HTML formatirano");
define("_PLAINTEXT","Normalen tekst");
define("_ONN","na...");
define("_SUBJECT","Naslov");
define("_COMMENTREPLY","Odgovori na komentar");
define("_COMREPLYPRE","Pregled/preverjanje pred poiljanjem");
define("_NOTRIGHT","Nekaj ni v redu s prehodom variable ez to funkcijo. Smisel tega sporoila je reevanje mogoih napak");
define("_SENDAMSG","Polji sporoilo");
define("_YOUSENDSTORY","Poslali boste zgodbo");
define("_TOAFRIEND","doloenemu prijatelju:");
define("_FYOURNAME","Vae ime:");
define("_FYOUREMAIL","Va E-mail:");
define("_FFRIENDNAME","Ime Vaega prijatelja:");
define("_FFRIENDEMAIL","E-mail Vaega prijatelja:");
define("_INTERESTING","Zanimiv lanek na");
define("_HELLO","Pozdravljen");
define("_YOURFRIEND","Vaemu prijatelju");
define("_CONSIDERED","se zdi sledei lanek zanimiv in Vam ga eli poslati.");
define("_FDATE","Datum:");
define("_FTOPIC","Naslov:");
define("_YOUCANREAD","Lahko prebere zanimiv lanek na");
define("_FSTORY","lanek");
define("_HASSENT","Je poslan na");
define("_THANKS","Hvala");
define("_RECOMMEND","Priporoi stran prijatelju");
define("_PDATE","Datum:");
define("_PTOPIC","Naslov:");
define("_COMESFROM","lanek prihaja od");
define("_THEURL","URL lanka je:");
define("_PREVIEW","Pregled");
define("_NEWUSER","Novi uporabnik");
define("_OPTIONS","Opcije");
define("_REFRESH","Osvei");
define("_ADD","Dodaj");
define("_NOCOMMENTSACT","Oprostite, komentarji za ta lanek niso dostopni.");
define("_ARTICLEPOLL","Anketa lanka");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
